==> boo_0.7.0.1921.orig.tar.gz: boo-0.7.0.1921/src/Boo.Lang.Compiler/Steps/ExpandAstLiterals.cs <==
﻿#region license
// Copyright (c) 2003, 2004, 2005 Rodrigo B. de Oliveira (rbo@acm.org)
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification,
// are permitted provided that the following conditions are met:
// 
//     * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//     * Neither the name of Rodrigo B. de Oliveira nor the names of its
//     contributors may be used to endorse or promote products derived from this
//     software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#endregion


using System;
using Boo.Lang.Compiler.Ast;

namespace Boo.Lang.Compiler.Steps
{
	public class ExpandAstLiterals : AbstractTransformerCompilerStep
	{	
		public ExpandAstLiterals()
		{
		}

        override public void Run()
        {
        	Visit(CompileUnit);
        }

        override public void OnAstLiteralExpression(AstLiteralExpression node)
        {
			Type type = node.Node.GetType();
			CastExpression ce = new CastExpression(CodeBuilder.CreateTypeReference(type), CreateFromXmlInvocation(node.Node.LexicalInfo, type, AstUtil.ToXml(node.Node)));
			ce.LexicalInfo = node.LexicalInfo;

			ReplaceCurrentNode(ce);
        }

		private Expression CreateFromXmlInvocation(LexicalInfo li, Type type, string xml)
		{
			MethodInvocationExpression e = new MethodInvocationExpression(li);
			e.Target = AstUtil.CreateReferenceExpression("Boo.Lang.Compiler.Ast.AstUtil.FromXml");
			e.Arguments.Add(CodeBuilder.CreateTypeofExpression(type));
			e.Arguments.Add(new StringLiteralExpression(xml));
			return e;
		}
	}
}

==> boo_0.7.6.2237.orig.tar.gz: boo-0.7.6.2237/src/Boo.Lang.Compiler/Steps/ExpandAstLiterals.cs <==
﻿#region license
// Copyright (c) 2003, 2004, 2005 Rodrigo B. de Oliveira (rbo@acm.org)
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification,
// are permitted provided that the following conditions are met:
// 
//     * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//     * Neither the name of Rodrigo B. de Oliveira nor the names of its
//     contributors may be used to endorse or promote products derived from this
//     software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#endregion


using System;
using Boo.Lang.Compiler.Ast;

namespace Boo.Lang.Compiler.Steps
{
	public class ExpandAstLiterals : AbstractTransformerCompilerStep
	{	
		public ExpandAstLiterals()
		{
		}

        override public void Run()
        {
	        	Visit(CompileUnit);
        }

        override public void OnAstLiteralExpression(AstLiteralExpression node)
        {
			Type type = node.Node.GetType();
			CastExpression ce = new CastExpression(CreateFromXmlInvocation(node.Node.LexicalInfo, type, AstUtil.ToXml(node.Node)), CodeBuilder.CreateTypeReference(type));
			ce.LexicalInfo = node.LexicalInfo;

			ReplaceCurrentNode(ce);
        }

		private Expression CreateFromXmlInvocation(LexicalInfo li, Type type, string xml)
		{
			MethodInvocationExpression e = new MethodInvocationExpression(li);
			e.Target = AstUtil.CreateReferenceExpression("Boo.Lang.Compiler.Ast.AstUtil.FromXml");
			e.Arguments.Add(CodeBuilder.CreateTypeofExpression(type));
			e.Arguments.Add(new StringLiteralExpression(xml));
			return e;
		}
	}
}
